@@ -142,19 +142,23 @@ void InfoTree::parseInfoDirFile( const QString &infoDirFileName )
       ;
   }
 
+  QHash< QChar, InfoCategoryItem * > alphabSections;
+
   while ( !stream.atEnd() ) {
     QString s = stream.readLine();
     if ( s.trimmed().isEmpty() )
       continue;
 
     InfoCategoryItem *catItem = new InfoCategoryItem( m_categoryItem, s );
-    while ( !stream.atEnd() && !s.trimmed().isEmpty() ) {
+    while ( !stream.atEnd() ) {
       s = stream.readLine();
-      if ( s[ 0 ] == '*' ) {
-        const int colon = s.indexOf( ":" );
-        const int openBrace = s.indexOf( "(", colon );
-        const int closeBrace = s.indexOf( ")", openBrace );
-        const int dot = s.indexOf( ".", closeBrace );
+      if ( s.isEmpty() )
+        break;
+      if ( s.at( 0 ) == QLatin1Char( '*' ) ) {
+        const int colon = s.indexOf( QLatin1Char( ':' ) );
+        const int openBrace = s.indexOf( QLatin1Char( '(' ), colon );
+        const int closeBrace = s.indexOf( QLatin1Char( ')' ), openBrace );
+        const int dot = s.indexOf( QLatin1Char( '.' ), closeBrace );
 
         QString appName = s.mid( 2, colon - 2 );
         QString url = "info:/" + s.mid( openBrace + 1, closeBrace - openBrace - 1 );
@@ -166,21 +170,13 @@ void InfoTree::parseInfoDirFile( const QString &infoDirFileName )
         InfoNodeItem *item = new InfoNodeItem( catItem, appName );
         item->entry()->setUrl( url );
 
-        InfoCategoryItem *alphabSection = 0;
-	
-	QTreeWidgetItemIterator it( m_alphabItem );
-	while ( (*it) ) 
-	{
-	  if ( (*it)->text( 0 ) == QString( appName[ 0 ].toUpper() ) ) 
-	  {
-	    alphabSection = static_cast<InfoCategoryItem *>( (*it) );
-	    break;
-	  }
-	  ++it;
-	}
+        const QChar first = appName.at( 0 ).toUpper();
+        InfoCategoryItem *alphabSection = alphabSections.value( first );
 
-        if ( alphabSection == 0 )
-          alphabSection = new InfoCategoryItem( m_alphabItem, QString( appName[ 0 ].toUpper() ) );
+        if ( alphabSection == 0 ) {
+          alphabSection = new InfoCategoryItem( m_alphabItem, QString( first ) );
+          alphabSections.insert( first, alphabSection );
+        }
 
         item = new InfoNodeItem( alphabSection, appName );
         item->entry()->setUrl( url );
